#ifndef EFL_CANVAS_GESTURE_MANAGER_IMPL_HH
#define EFL_CANVAS_GESTURE_MANAGER_IMPL_HH

#include "efl_canvas_gesture_manager.eo.hh"

namespace efl { namespace canvas { 
inline ::efl::eolian::return_traits< ::efl::eina::value_view>::type Gesture_Manager::config_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const
{
   Eina_Value * __return_value =  ::efl_gesture_manager_config_get(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::value_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Gesture_Manager::config_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name,  ::efl::eolian::in_traits< ::efl::eina::value_view>::type value) const
{
    ::efl_gesture_manager_config_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name)
      ,  ::efl::eolian::convert_to_c<Eina_Value *,  ::efl::eolian::in_traits< ::efl::eina::value_view>::type>(value));
}
inline ::efl::eolian::return_traits<Efl_Event_Description const&>::type Gesture_Manager::recognizer_register( ::efl::eolian::in_traits< ::efl::canvas::Gesture_Recognizer>::type recognizer) const
{
   const Efl_Event_Description * __return_value =  ::efl_gesture_manager_recognizer_register(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Gesture_Recognizer*,  ::efl::eolian::in_traits< ::efl::canvas::Gesture_Recognizer>::type>(recognizer));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Event_Description const&>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Gesture_Manager::recognizer_unregister( ::efl::eolian::in_traits< ::efl::canvas::Gesture_Recognizer>::type recognizer) const
{
    ::efl_gesture_manager_recognizer_unregister(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Gesture_Recognizer*,  ::efl::eolian::in_traits< ::efl::canvas::Gesture_Recognizer>::type>(recognizer));
}
} } 
namespace eo_cxx {
namespace efl { namespace canvas { 
inline ::efl::eolian::return_traits< ::efl::eina::value_view>::type Gesture_Manager::config_get( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name) const
{
   Eina_Value * __return_value =  ::efl_gesture_manager_config_get(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::value_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Gesture_Manager::config_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type name,  ::efl::eolian::in_traits< ::efl::eina::value_view>::type value) const
{
    ::efl_gesture_manager_config_set(_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(name)
      ,  ::efl::eolian::convert_to_c<Eina_Value *,  ::efl::eolian::in_traits< ::efl::eina::value_view>::type>(value));
}
inline ::efl::eolian::return_traits<Efl_Event_Description const&>::type Gesture_Manager::recognizer_register( ::efl::eolian::in_traits< ::efl::canvas::Gesture_Recognizer>::type recognizer) const
{
   const Efl_Event_Description * __return_value =  ::efl_gesture_manager_recognizer_register(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Gesture_Recognizer*,  ::efl::eolian::in_traits< ::efl::canvas::Gesture_Recognizer>::type>(recognizer));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Efl_Event_Description const&>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type Gesture_Manager::recognizer_unregister( ::efl::eolian::in_traits< ::efl::canvas::Gesture_Recognizer>::type recognizer) const
{
    ::efl_gesture_manager_recognizer_unregister(_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Gesture_Recognizer*,  ::efl::eolian::in_traits< ::efl::canvas::Gesture_Recognizer>::type>(recognizer));
}
inline efl::canvas::Gesture_Manager::operator ::efl::canvas::Gesture_Manager() const { return *static_cast< ::efl::canvas::Gesture_Manager const*>(static_cast<void const*>(this)); }
inline efl::canvas::Gesture_Manager::operator ::efl::canvas::Gesture_Manager&() { return *static_cast< ::efl::canvas::Gesture_Manager*>(static_cast<void*>(this)); }
inline efl::canvas::Gesture_Manager::operator ::efl::canvas::Gesture_Manager const&() const { return *static_cast< ::efl::canvas::Gesture_Manager const*>(static_cast<void const*>(this)); }
} } }
#endif
